/**
 * Sigma.js Settings
 * =================================
 *
 * The list of settings and some handy functions.
 * @module
 */
import { NodeKey, EdgeKey } from "graphology-types";
import drawLabel from "./rendering/canvas/label";
import drawHover from "./rendering/canvas/hover";
import drawEdgeLabel from "./rendering/canvas/edge-label";
import { EdgeAttributes, NodeAttributes } from "./types";
import { EdgeProgramConstructor } from "./rendering/webgl/programs/common/edge";
import { NodeProgramConstructor } from "./rendering/webgl/programs/common/node";
export declare function validateSettings(settings: Settings): void;
/**
 * Sigma.js settings
 * =================================
 */
export interface Settings {
    hideEdgesOnMove: boolean;
    hideLabelsOnMove: boolean;
    renderLabels: boolean;
    renderEdgeLabels: boolean;
    defaultNodeColor: string;
    defaultNodeType: string;
    defaultEdgeColor: string;
    defaultEdgeType: string;
    labelFont: string;
    labelSize: number;
    labelWeight: string;
    edgeLabelFont: string;
    edgeLabelSize: number;
    edgeLabelWeight: string;
    labelGrid: {
        cell: {
            width: number;
            height: number;
        } | null;
        renderedSizeThreshold: number;
    };
    nodeReducer: null | ((node: NodeKey, data: NodeAttributes) => NodeAttributes);
    edgeReducer: null | ((edge: EdgeKey, data: EdgeAttributes) => EdgeAttributes);
    zIndex: boolean;
    labelRenderer: typeof drawLabel;
    hoverRenderer: typeof drawHover;
    edgeLabelRenderer: typeof drawEdgeLabel;
    nodeProgramClasses: {
        [key: string]: NodeProgramConstructor;
    };
    edgeProgramClasses: {
        [key: string]: EdgeProgramConstructor;
    };
}
export declare const DEFAULT_SETTINGS: Settings;
